import { CfnOutput, Stage, StageProps } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { ApplicationStackFactory } from './application-stack-factory';
/**
 * The list of CICD Stages used in CICD Pipelines.
 */
export declare class CICDStage {
    readonly stage: string;
    /**
     * Prod stage
     */
    static readonly PROD: CICDStage;
    /**
     * Staging stage
     */
    static readonly STAGING: CICDStage;
    /**
     * Custom stage
     * @param stage the stage inside the pipeline
     * @returns
     */
    static of(stage: string): CICDStage;
    /**
     * @param stage the stage inside the pipeline
     */
    private constructor();
}
/**
 * Properties for the `ApplicationStage` class.
 */
export interface ApplicationStageProps extends StageProps {
    /**
     * The application CDK Stack Factory used to create application Stacks
     */
    readonly applicationStackFactory: ApplicationStackFactory;
    /**
     * The list of values to create CfnOutputs
     * @default - No CfnOutputs are created
     */
    readonly outputsEnv?: Record<string, string>;
    /**
     * The Stage to deploy the application CDK Stack in
     * @default - No stage is passed to the application stack
     */
    readonly stage: CICDStage;
}
/**
 * ApplicationStage class that creates a CDK Pipelines Stage from an ApplicationStackFactory.
 *
 */
export declare class ApplicationStage extends Stage {
    /**
     * The list of CfnOutputs created by the CDK Stack
     */
    readonly stackOutputsEnv?: Record<string, CfnOutput>;
    /**
     * Construct a new instance of the SparkCICDStage class.
     * @param scope the Scope of the CDK Construct
     * @param id the ID of the CDK Construct
     * @param props the ApplicationStage properties
     */
    constructor(scope: Construct, id: string, props: ApplicationStageProps);
}
